@@ -35,7 +35,7 @@
 #include "env.h"
 #include <string>
 #include "cec.h"
-#include <p8-platform/util/buffer.h>
+#include "p8-platform/util/buffer.h"
 #include "CECTypeUtils.h"
 #include <memory>
 
@@ -48,6 +48,13 @@ namespace CEC
   class CCECClient;
   typedef std::shared_ptr<CCECClient> CECClientPtr;
 
+  typedef struct cec_log_message_cpp
+  {
+    std::string   message; /**< the actual message, valid until returning from the log callback */
+    cec_log_level level;   /**< log level of the message */
+    int64_t       time;    /**< the timestamp of this message */
+  } cec_log_message_cpp;
+
   class CLibCEC : public ICECAdapter
   {
     public:
@@ -76,7 +83,7 @@ namespace CEC
       bool SetOSDString(cec_logical_address iLogicalAddress, cec_display_control duration, const char *strMessage);
       bool SwitchMonitoring(bool bEnable);
       cec_version GetDeviceCecVersion(cec_logical_address iAddress);
-      bool GetDeviceMenuLanguage(cec_logical_address iAddress, cec_menu_language *language);
+      std::string GetDeviceMenuLanguage(cec_logical_address iAddress);
       uint32_t GetDeviceVendorId(cec_logical_address iAddress);
       uint16_t GetDevicePhysicalAddress(cec_logical_address iAddress);
       cec_power_status GetDevicePowerStatus(cec_logical_address iAddress);
@@ -90,7 +97,7 @@ namespace CEC
       uint8_t MuteAudio(bool bSendRelease = true);
       bool SendKeypress(cec_logical_address iDestination, cec_user_control_code key, bool bWait = true);
       bool SendKeyRelease(cec_logical_address iDestination, bool bWait = true);
-      cec_osd_name GetDeviceOSDName(cec_logical_address iAddress);
+      std::string GetDeviceOSDName(cec_logical_address iAddress);
       cec_logical_address GetActiveSource(void);
       bool IsActiveSource(cec_logical_address iAddress);
       bool SetStreamPath(cec_logical_address iAddress);
@@ -145,6 +152,8 @@ namespace CEC
 
       cec_command CommandFromString(const char* strCommand);
 
+      bool AudioEnable(bool enable);
+
       CCECProcessor *           m_cec;
 
     protected:
