@@ -33,7 +33,7 @@
  */
 
 #include "env.h"
-#include <p8-platform/threads/mutex.h>
+#include "p8-platform/threads/mutex.h"
 #include "USBCECAdapterMessage.h"
 
 namespace CEC
@@ -135,6 +135,13 @@ namespace CEC
 
     void SetActiveSource(bool bSetTo, bool bClientUnregistered);
 
+    /*!
+     * @brief Change the value of the "auto enabled" setting.
+     * @param enabled The new value.
+     * @return True when changed and set, false otherwise.
+     */
+    bool SetSettingAutoEnabled(bool enabled);
+
   private:
     /*!
      * @brief Reads all settings from the eeprom.
@@ -149,13 +156,6 @@ namespace CEC
      */
     cec_datapacket RequestSetting(cec_adapter_messagecode msgCode);
 
-    /*!
-     * @brief Change the value of the "auto enabled" setting.
-     * @param enabled The new value.
-     * @return True when changed and set, false otherwise.
-     */
-    bool SetSettingAutoEnabled(bool enabled);
-
     /*!
      * @brief Request the value of the "auto enabled" setting from the adapter.
      * @return True when retrieved, false otherwise.
