@@ -33,7 +33,7 @@
  */
 
 #include "env.h"
-#include <p8-platform/threads/threads.h>
+#include "p8-platform/threads/threads.h"
 #include "adapter/AdapterCommunication.h"
 #include "USBCECAdapterMessage.h"
 
@@ -77,12 +77,13 @@ namespace CEC
 
     bool StartBootloader(void);
     bool SetLogicalAddresses(const cec_logical_addresses &addresses);
-    cec_logical_addresses GetLogicalAddresses(void);
+    cec_logical_addresses GetLogicalAddresses(void) const;
     bool PingAdapter(void);
     uint16_t GetFirmwareVersion(void);
     uint32_t GetFirmwareBuildDate(void);
     bool IsRunningLatestFirmware(void);
     bool PersistConfiguration(const libcec_configuration &configuration);
+    bool SetAutoMode(bool automode);
     bool GetConfiguration(libcec_configuration &configuration);
     std::string GetPortName(void);
     uint16_t GetPhysicalAddress(void);
@@ -131,7 +132,7 @@ namespace CEC
     /*!
      * @return True when initialised, false otherwise.
      */
-    bool IsInitialised(void);
+    bool IsInitialised(void) const;
 
     /*!
      * @brief Pings the adapter, checks the firmware version and sets controlled mode.
@@ -174,7 +175,7 @@ namespace CEC
     void ResetMessageQueue(void);
 
     P8PLATFORM::ISocket *                        m_port;                 /**< the com port connection */
-    P8PLATFORM::CMutex                           m_mutex;                /**< mutex for changes in this class */
+    mutable P8PLATFORM::CMutex                   m_mutex;                /**< mutex for changes in this class */
     uint8_t                                      m_iLineTimeout;         /**< the current line timeout on the CEC line */
     cec_logical_address                          m_lastPollDestination;  /**< the destination of the last poll message that was received */
     bool                                         m_bInitialised;         /**< true when the connection is initialised, false otherwise */
