@@ -36,7 +36,7 @@
 #if defined(HAVE_RPI_API)
 
 #include "adapter/AdapterCommunication.h"
-#include <p8-platform/threads/threads.h>
+#include "p8-platform/threads/threads.h"
 
 #define RPI_ADAPTER_VID 0x2708
 #define RPI_ADAPTER_PID 0x1001
@@ -71,13 +71,14 @@ namespace CEC
     bool SetLineTimeout(uint8_t UNUSED(iTimeout)) { return true; };
     bool StartBootloader(void) { return false; };
     bool SetLogicalAddresses(const cec_logical_addresses &addresses);
-    cec_logical_addresses GetLogicalAddresses(void);
+    cec_logical_addresses GetLogicalAddresses(void) const;
     bool PingAdapter(void) { return m_bInitialised; };
     uint16_t GetFirmwareVersion(void);
     uint32_t GetFirmwareBuildDate(void) { return 0; };
     bool IsRunningLatestFirmware(void) { return true; };
     bool PersistConfiguration(const libcec_configuration & UNUSED(configuration)) { return false; };
     bool GetConfiguration(libcec_configuration & UNUSED(configuration)) { return false; };
+    bool SetAutoMode(bool UNUSED(automode)) { return false; }
     std::string GetPortName(void) { std::string strReturn("RPI"); return strReturn; };
     uint16_t GetPhysicalAddress(void);
     bool SetControlledMode(bool UNUSED(controlled)) { return true; };
@@ -96,7 +97,7 @@ namespace CEC
     static void InitHost(void);
 
   private:
-    cec_logical_address GetLogicalAddress(void);
+    cec_logical_address GetLogicalAddress(void) const;
     bool UnregisterLogicalAddress(void);
     bool RegisterLogicalAddress(const cec_logical_address address, uint32_t iTimeoutMs = CEC_DEFAULT_CONNECT_TIMEOUT);
     void SetDisableCallback(const bool disable);
@@ -108,7 +109,7 @@ namespace CEC
 
     bool                          m_bLogicalAddressChanged;
     P8PLATFORM::CCondition<bool>  m_logicalAddressCondition;
-    P8PLATFORM::CMutex            m_mutex;
+    mutable P8PLATFORM::CMutex    m_mutex;
     VCHI_INSTANCE_T               m_vchi_instance;
     VCHI_CONNECTION_T *           m_vchi_connection;
     cec_logical_address           m_previousLogicalAddress;
